"use strict";
const SpellSettings = require("./CSpellSettingsServer");
const defaultLocal = 'en';
exports.defaultLanguageSettings = [
    { languageId: '*', local: 'en', dictionaries: ['wordsEn'], },
    { languageId: '*', local: 'en-US', dictionaries: ['wordsEn'], },
    { languageId: '*', local: 'en-GB', dictionaries: ['wordsEnGb'], },
    { languageId: '*', dictionaries: ['companies', 'softwareTerms', 'misc', 'filetypes'], },
    { languageId: 'python', allowCompoundWords: true, dictionaries: ['python'] },
    { languageId: 'go', allowCompoundWords: true, dictionaries: ['go'], },
    { languageId: 'c', allowCompoundWords: true, dictionaries: ['cpp'], },
    { languageId: 'cpp', allowCompoundWords: true, dictionaries: ['cpp'], },
    { languageId: 'csharp', allowCompoundWords: true, dictionaries: ['csharp', 'dotnet', 'npm'] },
    { languageId: 'javascript', dictionaries: ['typescript', 'node', 'npm'] },
    { languageId: 'javascriptreact', dictionaries: ['typescript', 'node', 'npm'] },
    { languageId: 'typescript', dictionaries: ['typescript', 'node', 'npm'] },
    { languageId: 'typescriptreact', dictionaries: ['typescript', 'node', 'npm'] },
    { languageId: 'html', dictionaries: ['html', 'fonts', 'typescript', 'css', 'npm'] },
    { languageId: 'latex', dictionaries: ['latex'] },
    { languageId: 'markdown', dictionaries: ['npm'] },
    { languageId: 'jade', dictionaries: ['html', 'fonts', 'typescript', 'css', 'npm'] },
    { languageId: 'json', dictionaries: ['node', 'npm'] },
    { languageId: 'pug', dictionaries: ['html', 'fonts', 'typescript', 'css', 'npm'] },
    { languageId: 'php', dictionaries: ['php', 'html', 'fonts', 'css', 'typescript', 'npm'] },
    { languageId: 'css', dictionaries: ['fonts', 'css'] },
    { languageId: 'less', dictionaries: ['fonts', 'css'] },
    { languageId: 'scss', dictionaries: ['fonts', 'css'] },
    { languageId: 'map', enabled: false },
    { languageId: 'image', enabled: false },
    { languageId: 'binary', enabled: false },
];
function getDefaultLanguageSettings() {
    return { languageSettings: exports.defaultLanguageSettings };
}
exports.getDefaultLanguageSettings = getDefaultLanguageSettings;
function NormalizeLocal(local) {
    return local.toLowerCase().replace(/[^a-z]/g, '');
}
function calcSettingsForLanguage(languageSettings, languageId, local) {
    local = NormalizeLocal(local);
    return exports.defaultLanguageSettings.concat(languageSettings)
        .filter(s => s.languageId === '*' || s.languageId === languageId)
        .filter(s => !s.local || NormalizeLocal(s.local) === local || s.local === '*')
        .reduce((langSetting, setting) => {
        const { allowCompoundWords = langSetting.allowCompoundWords, enabled } = setting;
        const dictionaries = mergeUnique(langSetting.dictionaries, setting.dictionaries);
        return { languageId, local, allowCompoundWords, dictionaries, enabled };
    });
}
exports.calcSettingsForLanguage = calcSettingsForLanguage;
function calcUserSettingsForLanguage(settings, languageId) {
    const { languageSettings = [], language: local = defaultLocal } = settings;
    const { allowCompoundWords = settings.allowCompoundWords, dictionaries, dictionaryDefinitions, enabled = settings.enabled, } = calcSettingsForLanguage(languageSettings, languageId, local);
    return SpellSettings.mergeSettings(settings, { enabled, allowCompoundWords, dictionaries, dictionaryDefinitions });
}
exports.calcUserSettingsForLanguage = calcUserSettingsForLanguage;
function calcSettingsForLanguageId(baseSettings, languageId) {
    const langIds = ['*'].concat(languageId instanceof Array ? languageId : [languageId]);
    const langSettings = langIds.reduce((settings, languageId) => {
        return calcUserSettingsForLanguage(settings, languageId);
    }, baseSettings);
    return langSettings;
}
exports.calcSettingsForLanguageId = calcSettingsForLanguageId;
function mergeUnique(a = [], b = []) {
    // Merge and Make unique
    return [...(new Set(a.concat(b)))];
}
//# sourceMappingURL=LanguageSettings.js.map